@@ -1,8 +1,8 @@
 # ###########################################################################
 #             Thomas Dreibholz's R Simulation Scripts Collection
-#                  Copyright (C) 2005-2019 Thomas Dreibholz
+#                  Copyright (C) 2005-2022 Thomas Dreibholz
 #
-#               Author: Thomas Dreibholz, dreibh@iem.uni-due.de
+#               Author: Thomas Dreibholz, thomas.dreibholz@gmail.com
 # ###########################################################################
 #
 # This program is free software: you can redistribute it and/or modify
@@ -18,7 +18,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-# Contact: dreibh@iem.uni-due.de
+# Contact: thomas.dreibholz@gmail.com
 
 
 # ###########################################################################
@@ -1520,7 +1520,7 @@ loadResults <- function(name, customFilter="", customFormatter=applyFormatter, q
    if(!quiet) {
       cat(sep="", "Loading from pipe [", dataInputCommand, "] ...\n")
    }
-   data <- read.table(pipe(dataInputCommand))
+   data <- read.table(pipe(dataInputCommand), header = TRUE)
    data <- customFormatter(data)
    return(data)
 }
@@ -1887,7 +1887,7 @@ createPlots <- function(simulationDirectory,
                pSortAscending   = pSortAscending,
                prePlotFunction  = prePlotFunction,
                postPlotFunction = postPlotFunction,
-               hideCurves       = hideCurves)               
+               hideCurves       = hideCurves)
       if(plotOwnOutput) {
          dev.off()
       }
